==> apache-streampipes-0.95.0-source-release.zip: apache-streampipes-0.95.0/streampipes-storage-couchdb/src/main/java/org/apache/streampipes/storage/couchdb/impl/PipelineElementTemplateStorageImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.apache.streampipes.storage.couchdb.impl;

import org.apache.streampipes.model.template.PipelineElementTemplate;
import org.apache.streampipes.storage.api.IPipelineElementTemplateStorage;
import org.apache.streampipes.storage.couchdb.dao.AbstractDao;
import org.apache.streampipes.storage.couchdb.utils.Utils;

import java.util.List;
import java.util.stream.Collectors;

public class PipelineElementTemplateStorageImpl extends AbstractDao<PipelineElementTemplate>
    implements IPipelineElementTemplateStorage {

  public PipelineElementTemplateStorageImpl() {
    super(Utils::getCouchDbPipelineElementTemplateClient, PipelineElementTemplate.class);
  }

  @Override
  public List<PipelineElementTemplate> getAll() {
    return findAll();
  }

  @Override
  public void createElement(PipelineElementTemplate element) {
    persist(element);
  }

  @Override
  public PipelineElementTemplate getElementById(String s) {
    return find(s).orElseThrow(RuntimeException::new);
  }

  @Override
  public PipelineElementTemplate updateElement(PipelineElementTemplate element) {
    update(element);
    return find(element.getCouchDbId()).orElseThrow(RuntimeException::new);
  }

  @Override
  public void deleteElement(PipelineElementTemplate element) {
    delete(element.getCouchDbId());
  }

  @Override
  public List<PipelineElementTemplate> getPipelineElementTemplatesforAppId(String appId) {
    return getAll()
        .stream()
        .filter(template -> template.getBasePipelineElementAppId().equals(appId))
        .collect(Collectors.toList());
  }
}

==> apache-streampipes-0.97.0-source-release.zip: apache-streampipes-0.97.0/streampipes-storage-couchdb/src/main/java/org/apache/streampipes/storage/couchdb/impl/PipelineElementTemplateStorageImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.apache.streampipes.storage.couchdb.impl;

import org.apache.streampipes.model.template.PipelineElementTemplate;
import org.apache.streampipes.storage.api.IPipelineElementTemplateStorage;
import org.apache.streampipes.storage.couchdb.dao.AbstractDao;
import org.apache.streampipes.storage.couchdb.utils.Utils;

import java.util.List;
import java.util.stream.Collectors;

public class PipelineElementTemplateStorageImpl extends AbstractDao<PipelineElementTemplate>
    implements IPipelineElementTemplateStorage {

  public PipelineElementTemplateStorageImpl() {
    super(Utils::getCouchDbPipelineElementTemplateClient, PipelineElementTemplate.class);
  }

  @Override
  public PipelineElementTemplate getElementById(String s) {
    return find(s).orElseThrow(RuntimeException::new);
  }

  @Override
  public PipelineElementTemplate updateElement(PipelineElementTemplate element) {
    update(element);
    return find(element.getCouchDbId()).orElseThrow(RuntimeException::new);
  }

  @Override
  public void deleteElement(PipelineElementTemplate element) {
    delete(element.getCouchDbId());
  }

  @Override
  public List<PipelineElementTemplate> getPipelineElementTemplatesforAppId(String appId) {
    return this.findAll()
        .stream()
        .filter(template -> template.getBasePipelineElementAppId().equals(appId))
        .collect(Collectors.toList());
  }
}
